/*
 * Autogenerated by the Meson build system.
 * Do not edit, your changes will be lost.
 */

#pragma once

/* This is the system name Nix expects for local running instance of Nix.

See the "system" setting for additional details */
#define NIX_LOCAL_SYSTEM "x86_64-linux"

/* FIXME: It's a bit peculiar that this needs to be exposed. The reason is that that it effects whether the settings struct in a header has a particular field. This is also odd, because it means when there is no ACL support one will just get an "unknown setting" warning from their configuration. */
#define NIX_SUPPORT_ACL 1

#define NIX_WITH_AWS_AUTH 1

